SpreadsheetManager class

Constructors

SpreadsheetManager(SheetsApi _api, String spreadsheetId)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spreadsheetId String
final

Methods

addWorksheet(String title) Future<void>
appendValues(String range, ValueRange valueRange, {String valueInputOption = 'USER_ENTERED'}) Future<AppendValuesResponse>
batchUpdate(List<Request> requests) Future<BatchUpdateSpreadsheetResponse>
get() Future<Spreadsheet>
getValues(String range) Future<ValueRange>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateValues(String range, ValueRange valueRange, {String valueInputOption = 'USER_ENTERED'}) Future<UpdateValuesResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited