Worksheet class

Constructors

Worksheet(SpreadsheetManager _spreadsheet, String _name, int _sheetId)

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
no setter

Methods

appendRows(List<List<Object?>> rows) Future<void>
getValues({String? range}) Future<List<List<Object?>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resize({int? rowCount, int? columnCount}) Future<void>
toString() String
A string representation of this object.
inherited
updateValues(String range, List<List<Object?>> values, {String valueInputOption = 'USER_ENTERED'}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited